import { ICalendarsRepository } from '@modules/calendar/repositories/ICalendarsRepository';
import { AppError } from '@shared/error/AppError';
import 'reflect-metadata';
import { inject, injectable } from 'tsyringe';

interface IRequest {
    title: string,
    information: string,
    date: string
}

@injectable()
class CreateCalendarUseCase {
    constructor(
        @inject('CalendarsRepository')
        private calendarsRepository: ICalendarsRepository
    ) {}
   
    async execute({title, information, date}: IRequest) {
        const calendarAlreadyExists = await this.calendarsRepository.findByTitle(title)
        if(calendarAlreadyExists) {
            throw new AppError('Calendar Already Exists', 400)
        }

        const calendar = await this.calendarsRepository.create({
            title,
            information,
            date
        })

        return calendar
    }
}

export {CreateCalendarUseCase}